import buildUrl from 'build-url'

export default (context, inject) => {
  const { store, $axios, $config } = context

  const engine = {
    lastFetched: [0, 0, 0, 0, 0],
    async start() {
      if (!store.state.engine.user) {
        if (!await this.fetchUserInfo()) {
          window.location.href = "/"
        }
      }
      this.fetchUpdate()
    },
    async fetchUpdate() {
      let delay = 0
      try {
        const url = buildUrl($config.serverBaseUrl, {
          path: '/api/sync',
          queryParams: {
            v: store.state.engine.version + 1,
            g: store.state.engine.user?.game,
          },
        })
        const response = await $axios.get(url)
        store.commit('engine/setJson', response.data)

        const role = store.state.engine.user?.role
        if (role === "gamemaster" || role === "admin") {
          const url = buildUrl($config.serverBaseUrl, {
            path: '/api/gameinfo',
            queryParams: { g: store.state.engine.user?.game },
          })
          const response = await $axios.get(url)
          store.commit('engine/setGameinfo', response.data)
        }
      } catch (e) {
        const { status, statusText } = e.response
        if (status != 200) {
          console.warn(`HTTP ${status} ${statusText}`)
          delay = 5000
          store.commit('engine/setVersion', -1)
        }
      }

      const now = new Date().getTime()
      const last = this.lastFetched.splice(0, 1)
      this.lastFetched.push(now)

      if (now - last < 1000) {
        console.warn('engine: respawning too fast, throttling down')
        delay = 5000
      }
      window.setTimeout(() => {
        this.fetchUpdate()
      }, delay)
    },

    async fetchUserInfo() {
      try {
        const user = await $axios.$get('/api/userinfo')
        store.commit('engine/setUser', user)
      } catch(e) {
        store.commit('engine/setUser', undefined)
        return false
      }

      return true
    },
  }
  inject('engine', engine)
}
