package handler

import (
	"encoding/json"
	"fmt"
	"net/http"
	"sirlab.de/go/knyt/user"
)

type gameLight struct {
	Players []string `json:"players"`
}

func (authMux *AuthMux) GetGameInfo(usr *user.User, w http.ResponseWriter, r *http.Request) {
	gameRef := r.URL.Query().Get("g")
	gm, err := authMux.app.GetGameById(gameRef)
	if err != nil {
		w.WriteHeader(http.StatusNotFound)
		fmt.Fprintf(w, "game not found")
		return
	}

	if !usr.IsGamemaster() || (usr.GetGameId() != gameRef && !usr.IsAdmin()) {
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	gmLight := gameLight{
		Players: gm.GetActivePlayers(),
	}

	w.Header().Add("Content-Type", "application/json")
	jsonString, _ := json.Marshal(gmLight)
	fmt.Fprintf(w, string(jsonString))
}
